summaryrefslogtreecommitdiff
path: root/llvm/lib/Bitcode/Reader/BitcodeReader.cpp
diff options
context:
space:
mode:
authorNikolas Klauser <nikolasklauser@berlin.de>2024-05-02 22:38:44 +0200
committerGitHub <noreply@github.com>2024-05-02 22:38:44 +0200
commit17f006207cb233e4988160fe8860cf082bbafe88 (patch)
treeb32b96952aa1860b40c92ad917666ec9e39ed958 /llvm/lib/Bitcode/Reader/BitcodeReader.cpp
parent9d4575c910c210c3780b1c882e09732464dd4f44 (diff)
[libc++] Granularize <ostream> (#85537)
This also includes `<__ostream/basic_ostream.h>` in `<sstream>` now, reducing the include time of `<complex>` from 819ms to 603ms.
Diffstat (limited to 'llvm/lib/Bitcode/Reader/BitcodeReader.cpp')
0 files changed, 0 insertions, 0 deletions